console.log('Iniciando PJe-Admissibilidade e PJe-Gestão.');

const listaTRTsAdmissibilidade = ['trt13', 'trt7', 'trt20'];
const listaTRTsGestao = ['trt13', 'trt6', 'trt19'];
const URL_AJUDA_ADMISSIBILIDADE = 'https://sites.google.com/trt13.jus.br/pje-admissibilidade';

const menuLateralSelector = "body > pje-root > mat-sidenav-container > mat-sidenav-content > div > pje-menu-lateral > nav";
waitForKeyElements(menuLateralSelector, function (elements) {
    const url = window.location.href;

    // PJe-Admissibilidade
    if (listaTRTsAdmissibilidade.some(trt => window.location.href.includes(trt))) {
        const controlador = new AdmissibilidadeControlador();
        controlador.acrescentarBotaoAdmissibilidade(menuLateralSelector);
        configurarObservadorPaginaTriagemOuAnalise();
    }

    // PJe-Gestão
    if (listaTRTsGestao.some(trt => window.location.href.includes(trt))) {
        main();
    }
});

const menuLateralSelectorAdmissibilidade = "body > pje-app-root > div > pje-app-execucao > div > div > execucao";
if (window.location.href.includes('pjeadmissibilidade')) {
    console.log('Iniciando PJe-Admissibilidade.');
    waitForKeyElements(menuLateralSelectorAdmissibilidade, function () {
        const url = window.location.href;
        console.log('Iniciou pjeadmissibilidade.');
        // PJe-Admissibilidade
        if (listaTRTsAdmissibilidade.some(trt => window.location.href.includes(trt))) {
            const controlador = new AdmissibilidadeControlador();
            controlador.acrescentarBotaoAdmissibilidade(menuLateralSelectorAdmissibilidade);
        }
    });
}


// exemplo: 0000540-70.2023.5.13.0029
function inserirIconeAdmissibilidade(obj, observer) {
    let isNovaVersaoSAO = false;
    const dominioPje = window.location.hostname;
    let PREFIXO_SAO13 = 'SAO13-'
    const CODIGO_CONSULTA_SAO_ANTIGO = 'AD02';
    const elementoVersaoSAO = document.querySelector('.version-tag');
    const VERSAO_SAO = parseInt(elementoVersaoSAO.innerText.split('.')[1]);

    // exemplo: 2.10.0 - ANGICO
    if (VERSAO_SAO > 9) {
        isNovaVersaoSAO = true;
    }

    if (!isNovaVersaoSAO) {
        PREFIXO_SAO13 = '';
    }

    // Verifica se a URL atual é 'https://pje.../lista-processos'
    const textoTriagem = 'Triagem';
    const textoAnaliseGabinete = 'Análise de Gabinete';

    if (!obj.inseriu && window.location.href.includes('lista-processos')) {
        const elementosSpan = Array.from(document.querySelectorAll('span'));
        const elementoTriagemOuAnalise = elementosSpan.find(elemento =>
            (elemento.textContent.includes(textoTriagem) || elemento.textContent.includes(textoAnaliseGabinete)));
        const elementosImgClipboard = document.querySelectorAll('pje-icone-clipboard');
        let indxElementoImgClipboard = 0;

        if (elementoTriagemOuAnalise) {
            const elementosProcesso = elementosSpan.filter(elemento => elemento.className === 'mat-tooltip-trigger' && elemento.textContent.includes('.5.'));

            elementosProcesso.forEach(elementoProcesso => {
                const imgElementIcone = document.createElement('i');
                imgElementIcone.style = 'color: #f51800;';
                imgElementIcone.classList.add('fas', 'fa-tasks');
                imgElementIcone.title = 'Admissibilidade';
                imgElementIcone.ariaLabel = 'Admissibilidade';

                const imgElementLinkAdmissibilidade = document.createElement('a');

                imgElementLinkAdmissibilidade.href = `https://${dominioPje}/pjeadmissibilidade/execucao/${PREFIXO_SAO13}${CODIGO_CONSULTA_SAO_ANTIGO}?${PREFIXO_SAO13}NUM_PROC_NULL=${elementoProcesso.textContent}`;
                imgElementLinkAdmissibilidade.target = '_blank';
                imgElementLinkAdmissibilidade.appendChild(imgElementIcone);

                const linkAjuda = document.createElement('a');
                linkAjuda.href = URL_AJUDA_ADMISSIBILIDADE;
                linkAjuda.target = '_blank';
                const elementIconeAjuda = document.createElement('i');
                elementIconeAjuda.style = 'color: #f51800; margin-left: 3px;';
                elementIconeAjuda.classList.add('fas', 'fa-question');
                elementIconeAjuda.title = 'Ajuda Admissibilidade';
                elementIconeAjuda.ariaLabel = 'Ajuda Admissibilidade';
                linkAjuda.appendChild(elementIconeAjuda);

                const elementoImgClipboard = elementosImgClipboard.item(indxElementoImgClipboard++);
                elementoImgClipboard.parentElement.appendChild(imgElementLinkAdmissibilidade);
                elementoImgClipboard.parentElement.appendChild(linkAjuda);
            });
            obj.inseriu = true;
        }
    } else {
        if (!window.location.href.includes('lista-processos')) {
            obj.inseriu = false;
        }
    }
}

// Necessario para passar parâmetro por referência
let objInseriuIconeEmTriagem = {inseriu: false};

function configurarObservadorPaginaTriagemOuAnalise() {
    const observer = new MutationObserver( (mutationsList, observer) => {
        inserirIconeAdmissibilidade(objInseriuIconeEmTriagem, observer);
    });

    // Configura o observador para observar todo o documento e suas mudanças
    observer.observe(document, {childList: true, subtree: true});
}
